@@ -39,9 +39,11 @@ class AbstractNameModel(models.Model):
     name = models.CharField(
         'Nombre',
         max_length=100,
-        primary_key=True
         )
 
     class Meta:
 
         abstract = True
+
+    def __str__(self):
+        return self.name
